# mbf_bam

Fast, multi-core read counters and the like based on the BAM fileformat and rust-htslib.


Part of the mbf_* suite from https://github.com/IMTMarburg


publish using 'docker run --rm -v $(pwd):/io ghcr.io/pyo3/maturin publish # or other maturin arguments'
for the manywheel stuff
